@@ -1,5 +1,6 @@
 #
 # Copyright 2014 Andrew Ayer
+# Copyright 2015-2020 Chris Lamb <lamby@debian.org>
 #
 # This file is part of strip-nondeterminism.
 #
@@ -25,7 +26,7 @@ use POSIX qw(tzset);
 
 our($VERSION, $canonical_time, $clamp_time, $verbose);
 
-$VERSION = '1.6.3'; # <https://semver.org/>
+$VERSION = '1.9.0'; # <https://semver.org/>
 
 sub init() {
 	$ENV{'TZ'} = 'UTC';
@@ -64,7 +65,7 @@ sub get_normalizer_for_file($) {
 		return _handler('gzip');
 	}
 	# jar
-	if (m/\.(jar|war|hpi|apk)$/
+	if (m/\.(jar|war|hpi|apk|sym)$/
 		&& _get_file_type($_) =~ m/(Java|Zip) archive data/) {
 		return _handler('jar');
 	}
